from db import get_user_details, get_all, get_5_ads_by_platform, user_ad_exists, save_user_ad, increment_count, get_ad_details, get_last_five_ads_not_in_user_ads
from divar import crawl_divar, crawl_sheypoor
from telegram import InlineKeyboardButton, InlineKeyboardMarkup
from logging_script import logger
from config import DB_FILE_PATH, ADMIN_IDs

# categories = ['apartment-sell', 'apartment-rent', 'commercial-sell', 'commercial-rent']

async def send_ads_to_user(context, user_id, ad_id):
    # Assuming get_ad_details is a function that returns ad details in the specified order
    (_, title, address, link, price, description, phone, photo_link, date, platform) = get_ad_details(ad_id)
    
    # Initialize a list to hold parts of the message
    message_parts = []

    # Append non-empty, non-None parts to the message_parts list
    if platform and not(platform=="None"):
        message_parts.append(f"\n{platform.strip()}")
    if title and not (title =="None") :
        message_parts.append(f"\n{title.strip()}")
    if address and not (address =="None") :
        message_parts.append(f"\n{address.strip()}")
    if price and not (price =="None"):
        message_parts.append(f"\n{price.strip()}")
    if description and not (description =="None"):
        message_parts.append(f"\n{description.strip()}")
    if phone and not (phone =="None"):
        message_parts.append(f"\n{phone.strip()}")
    if date and not (date =="None"):
        message_parts.append(f"\n{date.strip()}")

    # Join the parts into a single message string
    message_text = "".join(message_parts)
    inline_button = []
    if link and link != "None":
        inline_button.append([InlineKeyboardButton("مشاهده آگهی📄", url=link)])

    reply_markup = InlineKeyboardMarkup(inline_button) if inline_button else None
    
    # Send the message and the photo (if there is one)
    if photo_link and not (photo_link =="None"):
        if len(description) < 800:
            await context.bot.send_photo(chat_id=user_id, photo=photo_link, caption=message_text, reply_markup=reply_markup)

    else:
        await context.bot.send_message(chat_id=user_id, text=message_text, reply_markup=reply_markup)


async def send_post(context) -> None:
    all_user = get_all()
    for user_id in all_user:
        _, rs,rr,cs,cr, count = get_user_details(user_id)
        _count = 0
        if rs:
            ads = get_5_ads_by_platform("apartment-sell", user_id)
            for ad in ads:
                if not user_ad_exists(user_id, ad):
                    save_user_ad(user_id, ad)
                    _count += 1
                    try:
                        await send_ads_to_user(context, user_id, ad)
                    except:
                        _count -= 1
        if rr:
            ads = get_5_ads_by_platform("apartment-rent", user_id)
            for ad in ads:
                if not user_ad_exists(user_id, ad):
                    save_user_ad(user_id, ad)
                    _count += 1
                    try:
                        await send_ads_to_user(context, user_id, ad)
                    except:
                        _count -= 1
        if cs:
            ads = get_5_ads_by_platform("commercial-sell", user_id)
            for ad in ads:
                if not user_ad_exists(user_id, ad):
                    save_user_ad(user_id, ad)
                    _count += 1
                    try:
                        await send_ads_to_user(context, user_id, ad)
                    except:
                        _count -= 1
        if cr:
            ads = get_5_ads_by_platform("commercial-rent", user_id)
            for ad in ads:
                if not user_ad_exists(user_id, ad):
                    save_user_ad(user_id, ad)
                    _count += 1
                    try:
                        await send_ads_to_user(context, user_id, ad)
                    except:
                        _count -= 1
        increment_count(user_id, _count)    


async def crawl_platforms(context) -> None:
    # try:
    await crawl_divar()
    # except:
        # logger.info("Some problem in crawl divar")
    # try:
    await crawl_sheypoor()
    # except:
        # logger.info("Some problem in crawl sheypoor")



async def send_backup(context):
    for _id in ADMIN_IDs:
        try:
            with open(DB_FILE_PATH, 'rb') as document:
                await context.bot.send_document(chat_id=_id, document=document)
        except:
            print("-"*100)